@@ -1,10 +1,15 @@
+__all__ = (
+    "DriveStorage",
+    "MemoryStorage",
+)
+
 from pathlib import Path
 from typing import Union
 
 from .core import Storage
 
 
-class LocalStorage(Storage):
+class DriveStorage(Storage):
     def __init__(self, root: Union[Path, str], create: bool = False, **kwargs):
         root = Path(root)
         if create:
@@ -28,3 +33,21 @@ class LocalStorage(Storage):
 
     def delete(self, key: str):
         Path(self._root / key).unlink()
+
+
+class MemoryStorage(Storage):
+    def __init__(self, **kwargs):
+        self._memory = dict()
+        super().__init__(**kwargs)
+
+    def exists(self, key: str) -> bool:
+        return key in self._memory
+
+    def load(self, key: str) -> bytes:
+        return self._memory[key]
+
+    def save(self, key: str, data: bytes):
+        self._memory[key] = data
+
+    def delete(self, key: str):
+        del self._memory[key]
